@@ -746,6 +746,13 @@ The build result from a previous 'skaffold build --file-output' run can be used
 		DefValue:      false,
 		FlagAddMethod: "BoolVar",
 		DefinedOn:     []string{"dev", "debug"},
+	}, {
+		Name:          "set",
+		Usage:         "overrides templated manifest fields by provided key-value pairs",
+		Value:         &opts.ManifestsOverrides,
+		DefValue:      []string{},
+		FlagAddMethod: "StringSliceVar",
+		DefinedOn:     []string{"render"},
 	},
 }
 
