@@ -47,6 +47,8 @@ type RunBuilder struct {
 	stdin      []byte
 }
 
+const DefaultRepo = "us-central1-docker.pkg.dev/k8s-skaffold/testing"
+
 // Apply runs `skaffold apply` with the given arguments.
 func Apply(args ...string) *RunBuilder {
 	return withDefaults("apply", args)
@@ -144,7 +146,7 @@ func GeneratePipeline(args ...string) *RunBuilder {
 func withDefaults(command string, args []string) *RunBuilder {
 	repo := os.Getenv("DEFAULT_REPO")
 	if repo == "" {
-		repo = "us-central1-docker.pkg.dev/k8s-skaffold/testing"
+		repo = DefaultRepo
 	}
 	return &RunBuilder{command: command, args: args, repo: repo}
 }
