@@ -19,6 +19,7 @@ package testutil
 import (
 	"context"
 	"errors"
+	"fmt"
 	"io"
 	"os/exec"
 	"strings"
@@ -29,6 +30,7 @@ type FakeCmd struct {
 	t           *testing.T
 	runs        []run
 	timesCalled int
+	runOnce     map[string]run
 }
 
 type run struct {
@@ -42,7 +44,9 @@ type run struct {
 }
 
 func newFakeCmd() *FakeCmd {
-	return &FakeCmd{}
+	return &FakeCmd{
+		runOnce: map[string]run{},
+	}
 }
 
 func (c *FakeCmd) addRun(r run) *FakeCmd {
@@ -82,6 +86,10 @@ func CmdRunOut(command string, output string) *FakeCmd {
 	return newFakeCmd().AndRunOut(command, output)
 }
 
+func CmdRunOutOnce(command string, output string) *FakeCmd {
+	return newFakeCmd().AndRunOutOnce(command, output)
+}
+
 func CmdRunDirOut(command string, dir string, output string) *FakeCmd {
 	return newFakeCmd().AndRunDirOut(command, dir, output)
 }
@@ -145,6 +153,15 @@ func (c *FakeCmd) AndRunOut(command string, output string) *FakeCmd {
 	})
 }
 
+func (c *FakeCmd) AndRunOutOnce(command string, output string) *FakeCmd {
+	r := run{
+		command: command,
+		output:  []byte(output),
+	}
+	c.runOnce[command] = r
+	return c
+}
+
 func (c *FakeCmd) AndRunDirOut(command string, dir string, output string) *FakeCmd {
 	return c.addRun(run{
 		command: command,
@@ -195,6 +212,18 @@ func (c *FakeCmd) RunCmdOut(ctx context.Context, cmd *exec.Cmd) ([]byte, error)
 	return r.output, r.err
 }
 
+func (c *FakeCmd) RunCmdOutOnce(ctx context.Context, cmd *exec.Cmd) ([]byte, error) {
+	c.timesCalled++
+	command := strings.Join(cmd.Args, " ")
+
+	r, found := c.runOnce[command]
+	if !found {
+		return nil, fmt.Errorf("expected command not found: %s", command)
+	}
+
+	return r.output, r.err
+}
+
 func (c *FakeCmd) RunCmd(ctx context.Context, cmd *exec.Cmd) error {
 	c.timesCalled++
 	command := strings.Join(cmd.Args, " ")
